@@ -12,12 +12,17 @@ func PrivateKey() *config.Rule {
 		Description: "Private Key",
 		RuleID:      "private-key",
 		Regex:       regexp.MustCompile(`(?i)-----BEGIN[ A-Z0-9_-]{0,100}PRIVATE KEY-----[\s\S-]*KEY----`),
-		Keywords:    []string{"-----BEGIN PRIVATE"},
+		Keywords:    []string{"-----BEGIN"},
 	}
 
 	// validate
 	tps := []string{`-----BEGIN PRIVATE KEY-----
 anything
------END PRIVATE KEY-----`} // gitleaks:allow
+-----END PRIVATE KEY-----`,
+		`-----BEGIN RSA PRIVATE KEY-----
+abcdefghijklmnopqrstuvwxyz
+-----END RSA PRIVATE KEY-----
+`,
+	} // gitleaks:allow
 	return validate(r, tps, nil)
 }
